@@ -592,8 +592,22 @@ static int handler_writefile(int fd, ole2_header_t *hdr, property_t *prop, const
 			return FALSE;
 		}
 		snprintf(name, 11, "%.10ld", i + (long int) prop);
+	} else {
+		/* Sanitize the file name */
+                for(newname = name; *newname; newname++) {
+#ifdef  C_DARWIN
+                        *newname &= '\177';
+#endif
+#if     defined(MSDOS) || defined(C_CYGWIN) || defined(WIN32)
+                        if(strchr("/*?<>|\"+=,;: ", *newname))
+#else
+                        if(*newname == '/')
+#endif
+                                *newname = '_';
+                }
 	}
 
+
 	newname = (char *) cli_malloc(strlen(name) + strlen(dir) + 2);
 	if (!newname) {
 		free(name);
@@ -604,6 +618,8 @@ static int handler_writefile(int fd, ole2_header_t *hdr, property_t *prop, const
 
 	ofd = open(newname, O_WRONLY|O_CREAT|O_TRUNC, S_IRWXU);
 	if (ofd < 0) {
+		cli_errmsg("ERROR: failed to create file: %s\n", newname);
+		free(newname);
 		return FALSE;
 	}
 	free(newname);
@@ -767,6 +783,11 @@ int cli_ole2_extract(int fd, const char *dirname, const struct cl_limits *limits
 	
 	if (strncmp(hdr.magic, magic_id, 8) != 0) {
 		cli_dbgmsg("OLE2 magic failed!\n");
+#ifdef HAVE_MMAP
+		if (hdr.m_area != NULL) {
+			munmap(hdr.m_area, hdr.m_length);
+		}
+#endif
 		return CL_EOLE2;
 	}
 
