@@ -1,6 +1,5 @@
 /*
  *  Copyright (C) 2002 - 2004 Tomasz Kojm <tkojm@clamav.net>
- *  With enhancements from Thomas Lamy <Thomas.Lamy@in-online.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,18 +19,8 @@
 #ifndef __SCANNERS_H
 #define __SCANNERS_H
 
-typedef enum {
-    CL_UNKNOWN_TYPE = 0,
-    CL_DATAFILE,
-    CL_MAILFILE,
-    CL_GZFILE,
-    CL_ZIPFILE,
-    CL_BZFILE,
-    CL_RARFILE,
-    CL_MSCFILE,
-    CL_OLE2FILE,
-} cli_file_t;
+#include "clamav.h"
 
-cli_file_t cli_filetype(const char *buf, size_t buflen);
+int cli_magic_scandesc(int desc, const char **virname, long int *scanned, const struct cl_node *root, const struct cl_limits *limits, unsigned int options, int *arec, int *mrec);
 
 #endif
